@@ -14,7 +14,6 @@ from . import product
 import records
 import json
 
-
 __all__ = [
     'Customer',
     ]
@@ -189,16 +188,28 @@ class Customer(object):
     def get_cdr_from_aiguillier(self, last_date):
         """Récupération des CDRs des 30 derniers jours
         depuis l'API d'Aiguillier pour les clients business"""
+        import time
         url = core.database_url(**FUPDB_CREDENTIALS)
         LOGS.logger.warn('last date {} de {}'.format(last_date, self.name))
-        response = REST_CLIENT.get(
-            '/fup',
-            auth=(
-                CONFIG['AIGUILLIER']['username'],
-                CONFIG['AIGUILLIER']['password']
-                ),
-            params={'customer': self.name, 'fromdate': last_date}
-            )
+        OK = False
+        for i in range(3):
+            if OK:
+                break
+            try:
+                response = REST_CLIENT.get(
+                    '/fup',
+                    auth=(
+                        CONFIG['AIGUILLIER']['username'],
+                        CONFIG['AIGUILLIER']['password']
+                        ),
+                    params={'customer': self.name, 'fromdate': last_date}
+                    )
+                if response:
+                    OK = True
+            except ValueError:
+                LOGS.logger.debug("essai {} de {} ERROR".format(i, self.name))
+                time.sleep(60)
+                continue
         infos = response['content']
         LOGS.logger.warn('Value {}'.format(infos))
         # nill_condition = (
